@@ -758,7 +758,12 @@ class MessageProperties(object):
 
     @property
     def user_id(self):
-        return self._user_id
+        try:
+            if self._user_id is not None:
+                return self._user_id.value
+            return None
+        except AttributeError:
+            return self._user_id
 
     @user_id.setter
     def user_id(self, value):
@@ -766,7 +771,12 @@ class MessageProperties(object):
             value = value.encode(self._encoding)
         elif value is not None and not isinstance(value, six.binary_type):
             raise TypeError("user_id must be bytes or str.")
-        self._user_id = value
+        # user_id is type of binary according to the spec.
+        # convert byte string into bytearray then wrap the data into c_uamqp.BinaryValue.
+        if value is not None:
+            self._user_id = utils.data_factory(bytearray(value), encoding=self._encoding)
+        else:
+            self._user_id = None
 
     @property
     def to(self):
